We are developing Kùzu in a publicly open GitHub repo and encourage everyone
to comment and discuss topics related to Kùzu. However, we ask everyone to be
very respectful and polite in discussions and avoid any hurtful language in any form.
Kùzu is being developed in Canada, a land that is proud in their high standards
for politeness and where a person you bumped into on the road will likely
apologize to you even if it was your fault: so please be
kind and respectful to everyone.
If you prefer not to discuss something through open issues and discussions,
you can always reach us through [email](mailto:contact@kuzudb.com).
